/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package maloja

type GenericResult struct {
	Status string `json:"status"`
}

type GetScrobblesResult struct {
	GenericResult
	List       []Scrobble `json:"list"`
	Pagination Pagination `json:"pagination"`
}

type NewScrobbleResult struct {
	GenericResult
	Track       Track  `json:"track"`
	Description string `json:"desc"`
	Error       Error  `json:"error"`
}

type Scrobble struct {
	ListenedAt int64 `json:"time"`
	Duration   int64 `json:"duration"`
	// Maloja sets Origin to the name of the API key
	// prefixed with "client:"
	Origin string `json:"origin"`
	Track  Track  `json:"track"`
}

type NewScrobble struct {
	Key          string   `json:"key"`
	Artist       string   `json:"artist,omitempty"`
	Artists      []string `json:"artists,omitempty"`
	Title        string   `json:"title"`
	Album        string   `json:"album,omitempty"`
	AlbumArtists []string `json:"albumartists,omitempty"`
	Duration     int64    `json:"duration,omitempty"`
	Length       int64    `json:"length,omitempty"`
	Time         int64    `json:"time,omitempty"`
	Nofix        bool     `json:"nofix,omitempty"`
}

type Track struct {
	Title   string   `json:"title"`
	Artists []string `json:"artists"`
	Album   Album    `json:"album"`
	Length  int64    `json:"length"`
}

type Album struct {
	Title   string   `json:"albumtitle"`
	Artists []string `json:"artists"`
}

type Pagination struct {
	Page     int    `json:"page"`
	PerPage  int    `json:"perpage"`
	NextPage string `json:"next_page"`
	PrevPage string `json:"prev_page"`
}

type Error struct {
	Type        string `json:"type"`
	Value       string `json:"value"`
	Description string `json:"desc"`
}
